@@ -193,12 +193,6 @@ on the ordinary buffer.")
 	     (setq quotestr (concat quotestr (char-to-string char))))))
     (concat "\\`" result (regexp-quote quotestr) "\\'")))
 
-;;
-;; Section: X selection
-;;
-
-(defalias 'x-selection-exists-p 'w32-clipboard-data-exist-p)
-
 ;;
 ;; Section: Font
 ;;
